/********************************************************************************
** Form generated from reading UI file 'bulk-rename.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BULK_2D_RENAME_H
#define UI_BULK_2D_RENAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_BulkRenameDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *serialGroupBox;
    QVBoxLayout *verticalLayout_2;
    QLineEdit *lineEdit;
    QHBoxLayout *horizontalLayout;
    QLabel *startLabel;
    QSpinBox *spinBox;
    QSpacerItem *horizontalSpacer;
    QCheckBox *zeroBox;
    QCheckBox *localeBox;
    QGroupBox *replaceGroupBox;
    QFormLayout *formLayout;
    QLabel *findLabel;
    QLineEdit *findLineEdit;
    QLabel *replaceLabel;
    QLineEdit *replaceLineEdit;
    QCheckBox *caseBox;
    QCheckBox *regexBox;
    QGroupBox *caseGroupBox;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *upperCaseButton;
    QRadioButton *lowerCaseButton;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BulkRenameDialog)
    {
        if (BulkRenameDialog->objectName().isEmpty())
            BulkRenameDialog->setObjectName("BulkRenameDialog");
        verticalLayout = new QVBoxLayout(BulkRenameDialog);
        verticalLayout->setObjectName("verticalLayout");
        serialGroupBox = new QGroupBox(BulkRenameDialog);
        serialGroupBox->setObjectName("serialGroupBox");
        serialGroupBox->setCheckable(true);
        verticalLayout_2 = new QVBoxLayout(serialGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        lineEdit = new QLineEdit(serialGroupBox);
        lineEdit->setObjectName("lineEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lineEdit->sizePolicy().hasHeightForWidth());
        lineEdit->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(lineEdit);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        startLabel = new QLabel(serialGroupBox);
        startLabel->setObjectName("startLabel");

        horizontalLayout->addWidget(startLabel);

        spinBox = new QSpinBox(serialGroupBox);
        spinBox->setObjectName("spinBox");
        spinBox->setMinimum(-1000);
        spinBox->setMaximum(1000);

        horizontalLayout->addWidget(spinBox);

        horizontalSpacer = new QSpacerItem(0, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        zeroBox = new QCheckBox(serialGroupBox);
        zeroBox->setObjectName("zeroBox");

        verticalLayout_2->addWidget(zeroBox);

        localeBox = new QCheckBox(serialGroupBox);
        localeBox->setObjectName("localeBox");

        verticalLayout_2->addWidget(localeBox);


        verticalLayout->addWidget(serialGroupBox);

        replaceGroupBox = new QGroupBox(BulkRenameDialog);
        replaceGroupBox->setObjectName("replaceGroupBox");
        replaceGroupBox->setCheckable(true);
        replaceGroupBox->setChecked(false);
        formLayout = new QFormLayout(replaceGroupBox);
        formLayout->setObjectName("formLayout");
        findLabel = new QLabel(replaceGroupBox);
        findLabel->setObjectName("findLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, findLabel);

        findLineEdit = new QLineEdit(replaceGroupBox);
        findLineEdit->setObjectName("findLineEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, findLineEdit);

        replaceLabel = new QLabel(replaceGroupBox);
        replaceLabel->setObjectName("replaceLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, replaceLabel);

        replaceLineEdit = new QLineEdit(replaceGroupBox);
        replaceLineEdit->setObjectName("replaceLineEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, replaceLineEdit);

        caseBox = new QCheckBox(replaceGroupBox);
        caseBox->setObjectName("caseBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, caseBox);

        regexBox = new QCheckBox(replaceGroupBox);
        regexBox->setObjectName("regexBox");

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, regexBox);


        verticalLayout->addWidget(replaceGroupBox);

        caseGroupBox = new QGroupBox(BulkRenameDialog);
        caseGroupBox->setObjectName("caseGroupBox");
        caseGroupBox->setCheckable(true);
        caseGroupBox->setChecked(false);
        verticalLayout_3 = new QVBoxLayout(caseGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        upperCaseButton = new QRadioButton(caseGroupBox);
        upperCaseButton->setObjectName("upperCaseButton");
        upperCaseButton->setChecked(true);

        verticalLayout_3->addWidget(upperCaseButton);

        lowerCaseButton = new QRadioButton(caseGroupBox);
        lowerCaseButton->setObjectName("lowerCaseButton");

        verticalLayout_3->addWidget(lowerCaseButton);


        verticalLayout->addWidget(caseGroupBox);

        verticalSpacer_2 = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        verticalLayout->addItem(verticalSpacer_2);

        buttonBox = new QDialogButtonBox(BulkRenameDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(BulkRenameDialog);

        QMetaObject::connectSlotsByName(BulkRenameDialog);
    } // setupUi

    void retranslateUi(QDialog *BulkRenameDialog)
    {
        BulkRenameDialog->setWindowTitle(QCoreApplication::translate("BulkRenameDialog", "Bulk Rename", nullptr));
        serialGroupBox->setTitle(QCoreApplication::translate("BulkRenameDialog", "Serial Renaming", nullptr));
        lineEdit->setText(QCoreApplication::translate("BulkRenameDialog", "Name#", nullptr));
        startLabel->setText(QCoreApplication::translate("BulkRenameDialog", "# will be replaced by numbers starting with:", nullptr));
        zeroBox->setText(QCoreApplication::translate("BulkRenameDialog", "Pad numbers with zero if possible", nullptr));
        localeBox->setText(QCoreApplication::translate("BulkRenameDialog", "Use localized numbers", nullptr));
        replaceGroupBox->setTitle(QCoreApplication::translate("BulkRenameDialog", "Replacement", nullptr));
        findLabel->setText(QCoreApplication::translate("BulkRenameDialog", "Find in names:", nullptr));
        replaceLabel->setText(QCoreApplication::translate("BulkRenameDialog", "Replace with:", nullptr));
        caseBox->setText(QCoreApplication::translate("BulkRenameDialog", "Case-sensitive", nullptr));
        regexBox->setText(QCoreApplication::translate("BulkRenameDialog", "Regular expression", nullptr));
        caseGroupBox->setTitle(QCoreApplication::translate("BulkRenameDialog", "Change Case", nullptr));
        upperCaseButton->setText(QCoreApplication::translate("BulkRenameDialog", "To upper case", nullptr));
        lowerCaseButton->setText(QCoreApplication::translate("BulkRenameDialog", "To lower case", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BulkRenameDialog: public Ui_BulkRenameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BULK_2D_RENAME_H
