/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.FileManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef APPLICATIONADAPTORFREEDESKTOPFILEMANAGER_H
#define APPLICATIONADAPTORFREEDESKTOPFILEMANAGER_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "application.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.FileManager1
 */
class ApplicationAdaptorFreeDesktopFileManager: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.FileManager1")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.FileManager1\">\n"
"    <method name=\"ShowFolders\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"ShowItems\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"ShowItemProperties\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ApplicationAdaptorFreeDesktopFileManager(PCManFM::Application *parent);
    ~ApplicationAdaptorFreeDesktopFileManager() override;

    inline PCManFM::Application *parent() const
    { return static_cast<PCManFM::Application *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void ShowFolders(const QStringList &in0, const QString &in1);
    void ShowItemProperties(const QStringList &in0, const QString &in1);
    void ShowItems(const QStringList &in0, const QString &in1);
Q_SIGNALS: // SIGNALS
};

#endif
