/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../pcmanfm-qt-2.4.1/pcmanfm/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7PCManFM9ViewFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto PCManFM::ViewFrame::qt_create_metaobjectdata<qt_meta_tag_ZN7PCManFM9ViewFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PCManFM::ViewFrame"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ViewFrame, qt_meta_tag_ZN7PCManFM9ViewFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PCManFM::ViewFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM9ViewFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM9ViewFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PCManFM9ViewFrameE_t>.metaTypes,
    nullptr
} };

void PCManFM::ViewFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewFrame *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PCManFM::ViewFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::ViewFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM9ViewFrameE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int PCManFM::ViewFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN7PCManFM10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto PCManFM::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN7PCManFM10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PCManFM::MainWindow",
        "onPathEntryReturnPressed",
        "",
        "onPathBarChdir",
        "Fm::FilePath",
        "dirPath",
        "onPathBarMiddleClickChdir",
        "on_actionNewTab_triggered",
        "on_actionNewWin_triggered",
        "on_actionNewFolder_triggered",
        "on_actionNewBlankFile_triggered",
        "on_actionCloseTab_triggered",
        "on_actionCloseWindow_triggered",
        "on_actionFileProperties_triggered",
        "on_actionFolderProperties_triggered",
        "on_actionCut_triggered",
        "on_actionCopy_triggered",
        "on_actionPaste_triggered",
        "on_actionDelete_triggered",
        "on_actionRename_triggered",
        "on_actionBulkRename_triggered",
        "on_actionSelectAll_triggered",
        "on_actionDeselectAll_triggered",
        "on_actionInvertSelection_triggered",
        "on_actionPreferences_triggered",
        "on_actionGoBack_triggered",
        "on_actionGoForward_triggered",
        "on_actionGoUp_triggered",
        "on_actionHome_triggered",
        "on_actionReload_triggered",
        "on_actionConnectToServer_triggered",
        "on_actionIconView_triggered",
        "on_actionCompactView_triggered",
        "on_actionDetailedList_triggered",
        "on_actionThumbnailView_triggered",
        "on_actionGo_triggered",
        "on_actionShowHidden_triggered",
        "check",
        "on_actionShowThumbnails_triggered",
        "on_actionSplitView_triggered",
        "on_actionPreserveView_triggered",
        "checked",
        "on_actionPreserveViewRecursive_triggered",
        "on_actionGoToCustomizedViewSource_triggered",
        "on_actionByFileName_triggered",
        "on_actionByMTime_triggered",
        "on_actionByCrTime_triggered",
        "on_actionByDTime_triggered",
        "on_actionByOwner_triggered",
        "on_actionByGroup_triggered",
        "on_actionByFileType_triggered",
        "on_actionByFileSize_triggered",
        "on_actionAscending_triggered",
        "on_actionDescending_triggered",
        "on_actionFolderFirst_triggered",
        "on_actionHiddenLast_triggered",
        "on_actionCaseSensitive_triggered",
        "on_actionFilter_triggered",
        "on_actionUnfilter_triggered",
        "on_actionShowFilter_triggered",
        "on_actionLocationBar_triggered",
        "on_actionPathButtons_triggered",
        "on_actionApplications_triggered",
        "on_actionComputer_triggered",
        "on_actionTrash_triggered",
        "on_actionNetwork_triggered",
        "on_actionDesktop_triggered",
        "on_actionAddToBookmarks_triggered",
        "on_actionEditBookmarks_triggered",
        "on_actionOpenTerminal_triggered",
        "on_actionCreateLauncher_triggered",
        "on_actionOpenAsAdmin_triggered",
        "on_actionOpenAsRoot_triggered",
        "on_actionCopyFullPath_triggered",
        "on_actionFindFiles_triggered",
        "on_actionAbout_triggered",
        "on_actionHiddenShortcuts_triggered",
        "onBookmarkActionTriggered",
        "onTabBarCloseRequested",
        "index",
        "onTabBarCurrentChanged",
        "onTabBarTabMoved",
        "from",
        "to",
        "onShortcutPrevTab",
        "onShortcutNextTab",
        "onShortcutJumpToTab",
        "onStackedWidgetWidgetRemoved",
        "onTabPageTitleChanged",
        "onTabPageStatusChanged",
        "type",
        "statusText",
        "onTabPageSortFilterChanged",
        "onSidePaneChdirRequested",
        "path",
        "onSidePaneOpenFolderInNewWindowRequested",
        "onSidePaneOpenFolderInNewTabRequested",
        "onSidePaneOpenFolderInTerminalRequested",
        "onSidePaneCreateNewFolderRequested",
        "onSidePaneModeChanged",
        "Fm::SidePane::Mode",
        "mode",
        "on_actionSidePane_triggered",
        "onSplitterMoved",
        "pos",
        "onResetFocus",
        "onBackForwardContextMenu",
        "QPoint",
        "onFolderUnmounted",
        "tabContextMenu",
        "onTabBarClicked",
        "closeLeftTabs",
        "closeRightTabs",
        "closeOtherTabs",
        "focusPathEntry",
        "toggleMenuBar",
        "updateRecenMenu",
        "clearRecentMenu",
        "lanunchRecentFile",
        "detachTab",
        "onBookmarksChanged",
        "onSettingHiddenPlace",
        "str",
        "hide",
        "on_actionCleanPerFolderConfig_triggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onPathEntryReturnPressed'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onPathBarChdir'
        QtMocHelpers::SlotData<void(const Fm::FilePath &)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onPathBarMiddleClickChdir'
        QtMocHelpers::SlotData<void(const Fm::FilePath &)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'on_actionNewTab_triggered'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionNewWin_triggered'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionNewFolder_triggered'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionNewBlankFile_triggered'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCloseTab_triggered'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCloseWindow_triggered'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionFileProperties_triggered'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionFolderProperties_triggered'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCut_triggered'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCopy_triggered'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionPaste_triggered'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionDelete_triggered'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionRename_triggered'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionBulkRename_triggered'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionSelectAll_triggered'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionDeselectAll_triggered'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionInvertSelection_triggered'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionPreferences_triggered'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionGoBack_triggered'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionGoForward_triggered'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionGoUp_triggered'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionHome_triggered'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionReload_triggered'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionConnectToServer_triggered'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionIconView_triggered'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCompactView_triggered'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionDetailedList_triggered'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionThumbnailView_triggered'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionGo_triggered'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionShowHidden_triggered'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'on_actionShowThumbnails_triggered'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'on_actionSplitView_triggered'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'on_actionPreserveView_triggered'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionPreserveViewRecursive_triggered'
        QtMocHelpers::SlotData<void(bool)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionGoToCustomizedViewSource_triggered'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionByFileName_triggered'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByMTime_triggered'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByCrTime_triggered'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByDTime_triggered'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByOwner_triggered'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByGroup_triggered'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByFileType_triggered'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionByFileSize_triggered'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionAscending_triggered'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionDescending_triggered'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionFolderFirst_triggered'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionHiddenLast_triggered'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionCaseSensitive_triggered'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionFilter_triggered'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionUnfilter_triggered'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionShowFilter_triggered'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionLocationBar_triggered'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionPathButtons_triggered'
        QtMocHelpers::SlotData<void(bool)>(61, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'on_actionApplications_triggered'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionComputer_triggered'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionTrash_triggered'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionNetwork_triggered'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionDesktop_triggered'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionAddToBookmarks_triggered'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionEditBookmarks_triggered'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionOpenTerminal_triggered'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCreateLauncher_triggered'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionOpenAsAdmin_triggered'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionOpenAsRoot_triggered'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionCopyFullPath_triggered'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionFindFiles_triggered'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionAbout_triggered'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'on_actionHiddenShortcuts_triggered'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onBookmarkActionTriggered'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onTabBarCloseRequested'
        QtMocHelpers::SlotData<void(int)>(78, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'onTabBarCurrentChanged'
        QtMocHelpers::SlotData<void(int)>(80, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'onTabBarTabMoved'
        QtMocHelpers::SlotData<void(int, int)>(81, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 82 }, { QMetaType::Int, 83 },
        }}),
        // Slot 'onShortcutPrevTab'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onShortcutNextTab'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onShortcutJumpToTab'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onStackedWidgetWidgetRemoved'
        QtMocHelpers::SlotData<void(int)>(87, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'onTabPageTitleChanged'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onTabPageStatusChanged'
        QtMocHelpers::SlotData<void(int, QString)>(89, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 90 }, { QMetaType::QString, 91 },
        }}),
        // Slot 'onTabPageSortFilterChanged'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onSidePaneChdirRequested'
        QtMocHelpers::SlotData<void(int, const Fm::FilePath &)>(93, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 90 }, { 0x80000000 | 4, 94 },
        }}),
        // Slot 'onSidePaneOpenFolderInNewWindowRequested'
        QtMocHelpers::SlotData<void(const Fm::FilePath &)>(95, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 94 },
        }}),
        // Slot 'onSidePaneOpenFolderInNewTabRequested'
        QtMocHelpers::SlotData<void(const Fm::FilePath &)>(96, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 94 },
        }}),
        // Slot 'onSidePaneOpenFolderInTerminalRequested'
        QtMocHelpers::SlotData<void(const Fm::FilePath &)>(97, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 94 },
        }}),
        // Slot 'onSidePaneCreateNewFolderRequested'
        QtMocHelpers::SlotData<void(const Fm::FilePath &)>(98, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 94 },
        }}),
        // Slot 'onSidePaneModeChanged'
        QtMocHelpers::SlotData<void(Fm::SidePane::Mode)>(99, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 100, 101 },
        }}),
        // Slot 'on_actionSidePane_triggered'
        QtMocHelpers::SlotData<void(bool)>(102, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'onSplitterMoved'
        QtMocHelpers::SlotData<void(int, int)>(103, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 104 }, { QMetaType::Int, 79 },
        }}),
        // Slot 'onResetFocus'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onBackForwardContextMenu'
        QtMocHelpers::SlotData<void(QPoint)>(106, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 107, 104 },
        }}),
        // Slot 'onFolderUnmounted'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tabContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(109, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 107, 104 },
        }}),
        // Slot 'onTabBarClicked'
        QtMocHelpers::SlotData<void(int)>(110, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'closeLeftTabs'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'closeRightTabs'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'closeOtherTabs'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'focusPathEntry'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleMenuBar'
        QtMocHelpers::SlotData<void(bool)>(115, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'updateRecenMenu'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearRecentMenu'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'lanunchRecentFile'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'detachTab'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onBookmarksChanged'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onSettingHiddenPlace'
        QtMocHelpers::SlotData<void(const QString &, bool)>(121, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 122 }, { QMetaType::Bool, 123 },
        }}),
        // Slot 'on_actionCleanPerFolderConfig_triggered'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN7PCManFM10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PCManFM::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PCManFM10MainWindowE_t>.metaTypes,
    nullptr
} };

void PCManFM::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onPathEntryReturnPressed(); break;
        case 1: _t->onPathBarChdir((*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[1]))); break;
        case 2: _t->onPathBarMiddleClickChdir((*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[1]))); break;
        case 3: _t->on_actionNewTab_triggered(); break;
        case 4: _t->on_actionNewWin_triggered(); break;
        case 5: _t->on_actionNewFolder_triggered(); break;
        case 6: _t->on_actionNewBlankFile_triggered(); break;
        case 7: _t->on_actionCloseTab_triggered(); break;
        case 8: _t->on_actionCloseWindow_triggered(); break;
        case 9: _t->on_actionFileProperties_triggered(); break;
        case 10: _t->on_actionFolderProperties_triggered(); break;
        case 11: _t->on_actionCut_triggered(); break;
        case 12: _t->on_actionCopy_triggered(); break;
        case 13: _t->on_actionPaste_triggered(); break;
        case 14: _t->on_actionDelete_triggered(); break;
        case 15: _t->on_actionRename_triggered(); break;
        case 16: _t->on_actionBulkRename_triggered(); break;
        case 17: _t->on_actionSelectAll_triggered(); break;
        case 18: _t->on_actionDeselectAll_triggered(); break;
        case 19: _t->on_actionInvertSelection_triggered(); break;
        case 20: _t->on_actionPreferences_triggered(); break;
        case 21: _t->on_actionGoBack_triggered(); break;
        case 22: _t->on_actionGoForward_triggered(); break;
        case 23: _t->on_actionGoUp_triggered(); break;
        case 24: _t->on_actionHome_triggered(); break;
        case 25: _t->on_actionReload_triggered(); break;
        case 26: _t->on_actionConnectToServer_triggered(); break;
        case 27: _t->on_actionIconView_triggered(); break;
        case 28: _t->on_actionCompactView_triggered(); break;
        case 29: _t->on_actionDetailedList_triggered(); break;
        case 30: _t->on_actionThumbnailView_triggered(); break;
        case 31: _t->on_actionGo_triggered(); break;
        case 32: _t->on_actionShowHidden_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->on_actionShowThumbnails_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->on_actionSplitView_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->on_actionPreserveView_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->on_actionPreserveViewRecursive_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->on_actionGoToCustomizedViewSource_triggered(); break;
        case 38: _t->on_actionByFileName_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->on_actionByMTime_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->on_actionByCrTime_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->on_actionByDTime_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->on_actionByOwner_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->on_actionByGroup_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->on_actionByFileType_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->on_actionByFileSize_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->on_actionAscending_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->on_actionDescending_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->on_actionFolderFirst_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: _t->on_actionHiddenLast_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->on_actionCaseSensitive_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: _t->on_actionFilter_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->on_actionUnfilter_triggered(); break;
        case 53: _t->on_actionShowFilter_triggered(); break;
        case 54: _t->on_actionLocationBar_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 55: _t->on_actionPathButtons_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 56: _t->on_actionApplications_triggered(); break;
        case 57: _t->on_actionComputer_triggered(); break;
        case 58: _t->on_actionTrash_triggered(); break;
        case 59: _t->on_actionNetwork_triggered(); break;
        case 60: _t->on_actionDesktop_triggered(); break;
        case 61: _t->on_actionAddToBookmarks_triggered(); break;
        case 62: _t->on_actionEditBookmarks_triggered(); break;
        case 63: _t->on_actionOpenTerminal_triggered(); break;
        case 64: _t->on_actionCreateLauncher_triggered(); break;
        case 65: _t->on_actionOpenAsAdmin_triggered(); break;
        case 66: _t->on_actionOpenAsRoot_triggered(); break;
        case 67: _t->on_actionCopyFullPath_triggered(); break;
        case 68: _t->on_actionFindFiles_triggered(); break;
        case 69: _t->on_actionAbout_triggered(); break;
        case 70: _t->on_actionHiddenShortcuts_triggered(); break;
        case 71: _t->onBookmarkActionTriggered(); break;
        case 72: _t->onTabBarCloseRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 73: _t->onTabBarCurrentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 74: _t->onTabBarTabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 75: _t->onShortcutPrevTab(); break;
        case 76: _t->onShortcutNextTab(); break;
        case 77: _t->onShortcutJumpToTab(); break;
        case 78: _t->onStackedWidgetWidgetRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 79: _t->onTabPageTitleChanged(); break;
        case 80: _t->onTabPageStatusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 81: _t->onTabPageSortFilterChanged(); break;
        case 82: _t->onSidePaneChdirRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[2]))); break;
        case 83: _t->onSidePaneOpenFolderInNewWindowRequested((*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[1]))); break;
        case 84: _t->onSidePaneOpenFolderInNewTabRequested((*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[1]))); break;
        case 85: _t->onSidePaneOpenFolderInTerminalRequested((*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[1]))); break;
        case 86: _t->onSidePaneCreateNewFolderRequested((*reinterpret_cast<std::add_pointer_t<Fm::FilePath>>(_a[1]))); break;
        case 87: _t->onSidePaneModeChanged((*reinterpret_cast<std::add_pointer_t<Fm::SidePane::Mode>>(_a[1]))); break;
        case 88: _t->on_actionSidePane_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 89: _t->onSplitterMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 90: _t->onResetFocus(); break;
        case 91: _t->onBackForwardContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 92: _t->onFolderUnmounted(); break;
        case 93: _t->tabContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 94: _t->onTabBarClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 95: _t->closeLeftTabs(); break;
        case 96: _t->closeRightTabs(); break;
        case 97: _t->closeOtherTabs(); break;
        case 98: _t->focusPathEntry(); break;
        case 99: _t->toggleMenuBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 100: _t->updateRecenMenu(); break;
        case 101: _t->clearRecentMenu(); break;
        case 102: _t->lanunchRecentFile(); break;
        case 103: _t->detachTab(); break;
        case 104: _t->onBookmarksChanged(); break;
        case 105: _t->onSettingHiddenPlace((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 106: _t->on_actionCleanPerFolderConfig_triggered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        case 82:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        case 83:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        case 85:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        case 86:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Fm::FilePath >(); break;
            }
            break;
        }
    }
}

const QMetaObject *PCManFM::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int PCManFM::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 107)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 107;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 107)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 107;
    }
    return _id;
}
QT_WARNING_POP
