/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.FileManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "applicationadaptorfreedesktopfilemanager.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ApplicationAdaptorFreeDesktopFileManager
 */

ApplicationAdaptorFreeDesktopFileManager::ApplicationAdaptorFreeDesktopFileManager(PCManFM::Application *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ApplicationAdaptorFreeDesktopFileManager::~ApplicationAdaptorFreeDesktopFileManager()
{
    // destructor
}

void ApplicationAdaptorFreeDesktopFileManager::ShowFolders(const QStringList &in0, const QString &in1)
{
    // handle method call org.freedesktop.FileManager1.ShowFolders
    parent()->ShowFolders(in0, in1);
}

void ApplicationAdaptorFreeDesktopFileManager::ShowItemProperties(const QStringList &in0, const QString &in1)
{
    // handle method call org.freedesktop.FileManager1.ShowItemProperties
    parent()->ShowItemProperties(in0, in1);
}

void ApplicationAdaptorFreeDesktopFileManager::ShowItems(const QStringList &in0, const QString &in1)
{
    // handle method call org.freedesktop.FileManager1.ShowItems
    parent()->ShowItems(in0, in1);
}


#include "moc_applicationadaptorfreedesktopfilemanager.cpp"
