/****************************************************************************
** Meta object code from reading C++ file 'applicationadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "applicationadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'applicationadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ApplicationAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ApplicationAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18ApplicationAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ApplicationAdaptor",
        "D-Bus Interface",
        "org.pcmanfm.Application",
        "D-Bus Introspection",
        "  <interface name=\"org.pcmanfm.Application\">\n    <method name=\""
        "preferences\">\n      <arg direction=\"in\" type=\"s\"/>\n    </me"
        "thod>\n    <method name=\"desktopPrefrences\">\n      <arg directi"
        "on=\"in\" type=\"s\"/>\n    </method>\n    <method name=\"desktopM"
        "anager\">\n      <arg direction=\"in\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"launchFiles\">\n      <arg direction=\"in\" t"
        "ype=\"s\"/>\n      <arg direction=\"in\" type=\"as\"/>\n      <arg"
        " direction=\"in\" type=\"b\"/>\n      <arg direction=\"in\" type=\""
        "b\"/>\n    </method>\n    <method name=\"quit\"/>\n    <method nam"
        "e=\"setWallpaper\">\n      <arg direction=\"in\" type=\"s\"/>\n   "
        "   <arg direction=\"in\" type=\"s\"/>\n    </method>\n    <method "
        "name=\"findFiles\">\n      <arg direction=\"in\" type=\"as\"/>\n  "
        "  </method>\n    <property access=\"read\" type=\"b\" name=\"deskt"
        "opManagerEnabled\"/>\n  </interface>\n",
        "desktopManager",
        "",
        "in0",
        "desktopPrefrences",
        "findFiles",
        "launchFiles",
        "in1",
        "in2",
        "in3",
        "preferences",
        "quit",
        "setWallpaper",
        "desktopManagerEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'desktopManager'
        QtMocHelpers::SlotData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'desktopPrefrences'
        QtMocHelpers::SlotData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'findFiles'
        QtMocHelpers::SlotData<void(const QStringList &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'launchFiles'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &, bool, bool)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 11 }, { QMetaType::Bool, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'preferences'
        QtMocHelpers::SlotData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWallpaper'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'desktopManagerEnabled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ApplicationAdaptor, qt_meta_tag_ZN18ApplicationAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ApplicationAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ApplicationAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ApplicationAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ApplicationAdaptorE_t>.metaTypes,
    nullptr
} };

void ApplicationAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ApplicationAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->desktopManager((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->desktopPrefrences((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->findFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->launchFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 4: _t->preferences((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->quit(); break;
        case 6: _t->setWallpaper((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->desktopManagerEnabled(); break;
        default: break;
        }
    }
}

const QMetaObject *ApplicationAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ApplicationAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ApplicationAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ApplicationAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
