/****************************************************************************
** Meta object code from reading C++ file 'desktopwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../pcmanfm-qt-2.4.1/pcmanfm/desktopwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'desktopwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7PCManFM13DesktopWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto PCManFM::DesktopWindow::qt_create_metaobjectdata<qt_meta_tag_ZN7PCManFM13DesktopWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PCManFM::DesktopWindow",
        "onDesktopPreferences",
        "",
        "onCreatingShortcut",
        "selectAll",
        "invertSelection",
        "toggleDesktop",
        "onRowsAboutToBeRemoved",
        "QModelIndex",
        "parent",
        "start",
        "end",
        "onRowsInserted",
        "onLayoutChanged",
        "onModelSortFilterChanged",
        "onFolderStartLoading",
        "onFolderFinishLoading",
        "onFilesAdded",
        "Fm::FileInfoList",
        "files",
        "relayoutItems",
        "onStickToCurrentPos",
        "toggled",
        "onCutActivated",
        "onCopyActivated",
        "onCopyFullPathActivated",
        "onPasteActivated",
        "onRenameActivated",
        "onBulkRenameActivated",
        "onDeleteActivated",
        "onFilePropertiesActivated",
        "updateTrashIcon",
        "onInlineRenaming",
        "oldName",
        "newName",
        "onDecidingDrop",
        "accepted"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onDesktopPreferences'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onCreatingShortcut'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'invertSelection'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleDesktop'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'onRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'onLayoutChanged'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onModelSortFilterChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onFolderStartLoading'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onFolderFinishLoading'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onFilesAdded'
        QtMocHelpers::SlotData<void(const Fm::FileInfoList)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'relayoutItems'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onStickToCurrentPos'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'onCutActivated'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onCopyActivated'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onCopyFullPathActivated'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onPasteActivated'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onRenameActivated'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onBulkRenameActivated'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onDeleteActivated'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onFilePropertiesActivated'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateTrashIcon'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onInlineRenaming'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'onDecidingDrop'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DesktopWindow, qt_meta_tag_ZN7PCManFM13DesktopWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PCManFM::DesktopWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<View::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM13DesktopWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM13DesktopWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PCManFM13DesktopWindowE_t>.metaTypes,
    nullptr
} };

void PCManFM::DesktopWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DesktopWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onDesktopPreferences(); break;
        case 1: _t->onCreatingShortcut(); break;
        case 2: _t->selectAll(); break;
        case 3: _t->invertSelection(); break;
        case 4: _t->toggleDesktop(); break;
        case 5: _t->onRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->onRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->onLayoutChanged(); break;
        case 8: _t->onModelSortFilterChanged(); break;
        case 9: _t->onFolderStartLoading(); break;
        case 10: _t->onFolderFinishLoading(); break;
        case 11: _t->onFilesAdded((*reinterpret_cast<std::add_pointer_t<Fm::FileInfoList>>(_a[1]))); break;
        case 12: _t->relayoutItems(); break;
        case 13: _t->onStickToCurrentPos((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->onCutActivated(); break;
        case 15: _t->onCopyActivated(); break;
        case 16: _t->onCopyFullPathActivated(); break;
        case 17: _t->onPasteActivated(); break;
        case 18: _t->onRenameActivated(); break;
        case 19: _t->onBulkRenameActivated(); break;
        case 20: _t->onDeleteActivated(); break;
        case 21: _t->onFilePropertiesActivated(); break;
        case 22: _t->updateTrashIcon(); break;
        case 23: _t->onInlineRenaming((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->onDecidingDrop((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PCManFM::DesktopWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::DesktopWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM13DesktopWindowE_t>.strings))
        return static_cast<void*>(this);
    return View::qt_metacast(_clname);
}

int PCManFM::DesktopWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = View::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
