/****************************************************************************
** Meta object code from reading C++ file 'tabpage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../pcmanfm-qt-2.4.1/pcmanfm/tabpage.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7PCManFM10FilterEditE_t {};
} // unnamed namespace

template <> constexpr inline auto PCManFM::FilterEdit::qt_create_metaobjectdata<qt_meta_tag_ZN7PCManFM10FilterEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PCManFM::FilterEdit",
        "lostFocus",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lostFocus'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FilterEdit, qt_meta_tag_ZN7PCManFM10FilterEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PCManFM::FilterEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM10FilterEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM10FilterEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PCManFM10FilterEditE_t>.metaTypes,
    nullptr
} };

void PCManFM::FilterEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilterEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lostFocus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilterEdit::*)()>(_a, &FilterEdit::lostFocus, 0))
            return;
    }
}

const QMetaObject *PCManFM::FilterEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::FilterEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM10FilterEditE_t>.strings))
        return static_cast<void*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int PCManFM::FilterEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PCManFM::FilterEdit::lostFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN7PCManFM9FilterBarE_t {};
} // unnamed namespace

template <> constexpr inline auto PCManFM::FilterBar::qt_create_metaobjectdata<qt_meta_tag_ZN7PCManFM9FilterBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PCManFM::FilterBar",
        "textChanged",
        "",
        "text",
        "lostFocus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'lostFocus'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FilterBar, qt_meta_tag_ZN7PCManFM9FilterBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PCManFM::FilterBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM9FilterBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM9FilterBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PCManFM9FilterBarE_t>.metaTypes,
    nullptr
} };

void PCManFM::FilterBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilterBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->lostFocus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilterBar::*)(const QString & )>(_a, &FilterBar::textChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterBar::*)()>(_a, &FilterBar::lostFocus, 1))
            return;
    }
}

const QMetaObject *PCManFM::FilterBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::FilterBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM9FilterBarE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int PCManFM::FilterBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void PCManFM::FilterBar::textChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PCManFM::FilterBar::lostFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN7PCManFM7TabPageE_t {};
} // unnamed namespace

template <> constexpr inline auto PCManFM::TabPage::qt_create_metaobjectdata<qt_meta_tag_ZN7PCManFM7TabPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PCManFM::TabPage",
        "statusChanged",
        "",
        "type",
        "statusText",
        "titleChanged",
        "sortFilterChanged",
        "forwardRequested",
        "backwardRequested",
        "folderUnmounted",
        "backspacePressed",
        "onSelChanged",
        "onUiUpdated",
        "onFileSizeChanged",
        "QModelIndex",
        "index",
        "onFilesAdded",
        "Fm::FileInfoList",
        "files",
        "onFilterStringChanged",
        "str",
        "onLosingFilterBarFocus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(int, QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortFilterChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forwardRequested'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backwardRequested'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderUnmounted'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backspacePressed'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSelChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onUiUpdated'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onFileSizeChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onFilesAdded'
        QtMocHelpers::SlotData<void(const Fm::FileInfoList)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'onFilterStringChanged'
        QtMocHelpers::SlotData<void(QString)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'onLosingFilterBarFocus'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabPage, qt_meta_tag_ZN7PCManFM7TabPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PCManFM::TabPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM7TabPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM7TabPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PCManFM7TabPageE_t>.metaTypes,
    nullptr
} };

void PCManFM::TabPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->sortFilterChanged(); break;
        case 3: _t->forwardRequested(); break;
        case 4: _t->backwardRequested(); break;
        case 5: _t->folderUnmounted(); break;
        case 6: _t->backspacePressed(); break;
        case 7: _t->onSelChanged(); break;
        case 8: _t->onUiUpdated(); break;
        case 9: _t->onFileSizeChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->onFilesAdded((*reinterpret_cast<std::add_pointer_t<Fm::FileInfoList>>(_a[1]))); break;
        case 11: _t->onFilterStringChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->onLosingFilterBarFocus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)(int , QString )>(_a, &TabPage::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)()>(_a, &TabPage::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)()>(_a, &TabPage::sortFilterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)()>(_a, &TabPage::forwardRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)()>(_a, &TabPage::backwardRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)()>(_a, &TabPage::folderUnmounted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabPage::*)()>(_a, &TabPage::backspacePressed, 6))
            return;
    }
}

const QMetaObject *PCManFM::TabPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PCManFM::TabPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PCManFM7TabPageE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int PCManFM::TabPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void PCManFM::TabPage::statusChanged(int _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void PCManFM::TabPage::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PCManFM::TabPage::sortFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PCManFM::TabPage::forwardRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PCManFM::TabPage::backwardRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PCManFM::TabPage::folderUnmounted()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PCManFM::TabPage::backspacePressed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
