/********************************************************************************
** Form generated from reading UI file 'connect.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECT_H
#define UI_CONNECT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_ConnectServerDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QComboBox *serverType;
    QLabel *label_3;
    QLineEdit *host;
    QLabel *label_4;
    QSpinBox *port;
    QLabel *label_5;
    QLineEdit *path;
    QRadioButton *anonymousLogin;
    QRadioButton *loginAsUser;
    QLineEdit *userName;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ConnectServerDialog)
    {
        if (ConnectServerDialog->objectName().isEmpty())
            ConnectServerDialog->setObjectName("ConnectServerDialog");
        ConnectServerDialog->resize(450, 256);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("folder-remote")));
        ConnectServerDialog->setWindowIcon(icon);
        gridLayout = new QGridLayout(ConnectServerDialog);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ConnectServerDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label, 0, 0, 1, 4);

        label_2 = new QLabel(ConnectServerDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        serverType = new QComboBox(ConnectServerDialog);
        serverType->setObjectName("serverType");

        gridLayout->addWidget(serverType, 1, 1, 1, 3);

        label_3 = new QLabel(ConnectServerDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        host = new QLineEdit(ConnectServerDialog);
        host->setObjectName("host");

        gridLayout->addWidget(host, 2, 1, 1, 1);

        label_4 = new QLabel(ConnectServerDialog);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 2, 1, 1);

        port = new QSpinBox(ConnectServerDialog);
        port->setObjectName("port");
        port->setMaximum(65535);

        gridLayout->addWidget(port, 2, 3, 1, 1);

        label_5 = new QLabel(ConnectServerDialog);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        path = new QLineEdit(ConnectServerDialog);
        path->setObjectName("path");

        gridLayout->addWidget(path, 4, 1, 1, 3);

        anonymousLogin = new QRadioButton(ConnectServerDialog);
        anonymousLogin->setObjectName("anonymousLogin");
        anonymousLogin->setChecked(true);

        gridLayout->addWidget(anonymousLogin, 5, 0, 1, 4);

        loginAsUser = new QRadioButton(ConnectServerDialog);
        loginAsUser->setObjectName("loginAsUser");

        gridLayout->addWidget(loginAsUser, 6, 0, 1, 1);

        userName = new QLineEdit(ConnectServerDialog);
        userName->setObjectName("userName");

        gridLayout->addWidget(userName, 6, 1, 1, 3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ConnectServerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 8, 0, 1, 4);


        retranslateUi(ConnectServerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ConnectServerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ConnectServerDialog, qOverload<>(&QDialog::reject));
        QObject::connect(loginAsUser, &QRadioButton::toggled, userName, &QLineEdit::setEnabled);

        QMetaObject::connectSlotsByName(ConnectServerDialog);
    } // setupUi

    void retranslateUi(QDialog *ConnectServerDialog)
    {
        ConnectServerDialog->setWindowTitle(QCoreApplication::translate("ConnectServerDialog", "Connect to remote server", nullptr));
        label->setText(QCoreApplication::translate("ConnectServerDialog", "Specify remote folder to connect", nullptr));
        label_2->setText(QCoreApplication::translate("ConnectServerDialog", "Type:", nullptr));
        label_3->setText(QCoreApplication::translate("ConnectServerDialog", "Host:", nullptr));
        label_4->setText(QCoreApplication::translate("ConnectServerDialog", "Port:", nullptr));
        label_5->setText(QCoreApplication::translate("ConnectServerDialog", "Path:", nullptr));
        anonymousLogin->setText(QCoreApplication::translate("ConnectServerDialog", "Anonymous &login", nullptr));
        loginAsUser->setText(QCoreApplication::translate("ConnectServerDialog", "Login as &user:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ConnectServerDialog: public Ui_ConnectServerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONNECT_H
